@@ -3,6 +3,7 @@ import base64
 import atexit
 import uuid
 import os
+import sys
 import json
 import shutil
 import subprocess
@@ -83,7 +84,7 @@ class KernelSession:
         self.client = self.km.client()
         self.client.start_channels()
         self.is_active = True
-        print(f"Kernel Session '{self.session_id}' Started")
+        print(f"Kernel Session '{self.session_id}' Started", file=sys.stderr)
         
     def stop(self):
         """Stop this kernel session."""
@@ -93,7 +94,7 @@ class KernelSession:
         if self.km and self.km.is_alive():
             self.km.shutdown_kernel(now=True)
         self.is_active = False
-        print(f"Kernel Session '{self.session_id}' Stopped")
+        print(f"Kernel Session '{self.session_id}' Stopped", file=sys.stderr)
         
     def get_client(self):
         """Get the kernel client for this session."""
@@ -291,7 +292,7 @@ class KernelManagerSingleton:
             cls._instance = super(KernelManagerSingleton, cls).__new__(cls)
             cls._timeout_config = TimeoutConfig()
             cls._session_manager = SessionManager(cls._timeout_config)
-            print("Session-based Kernel Manager Initialized")
+            print("Session-based Kernel Manager Initialized", file=sys.stderr)
         return cls._instance
 
     def get_client(self):
@@ -1497,6 +1498,7 @@ def main():
     """Main entry point for the Python MCP Server."""
     parser = argparse.ArgumentParser(description="Python Interpreter MCP")
     parser.add_argument("--workspace", type=str, default=os.environ.get("MCP_WORKSPACE_DIR", "workspace"), help="Workspace directory for files, scripts, outputs")
+    parser.add_argument("--transport", type=str, default="stdio", choices=["stdio", "http"], help="Transport mode (default: stdio)")
     parser.add_argument("--host", type=str, default="127.0.0.1")
     parser.add_argument("--port", type=int, default=8000)
     args = parser.parse_args()
@@ -1511,7 +1513,10 @@ def main():
         for d in (WORKSPACE_DIR, SCRIPTS_DIR, OUTPUTS_DIR, UPLOADS_DIR):
             d.mkdir(parents=True, exist_ok=True)
 
-    mcp.run(transport="http", host=args.host, port=args.port)
+    if args.transport == "stdio":
+        mcp.run(transport="stdio")
+    else:
+        mcp.run(transport="http", host=args.host, port=args.port)
 
 
 if __name__ == "__main__":
